/* media-manager.c generated by valac 0.25.1.6-a1f05, the Vala compiler
 * generated from media-manager.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gudev/gudev.h>
#include <libtracker-sparql/tracker-sparql.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesMediaManagerPrivate BoxesMediaManagerPrivate;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_INSTALLED_MEDIA (boxes_installed_media_get_type ())
#define BOXES_INSTALLED_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMedia))
#define BOXES_INSTALLED_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMediaClass))
#define BOXES_IS_INSTALLED_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLED_MEDIA))
#define BOXES_IS_INSTALLED_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLED_MEDIA))
#define BOXES_INSTALLED_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMediaClass))

typedef struct _BoxesInstalledMedia BoxesInstalledMedia;
typedef struct _BoxesInstalledMediaClass BoxesInstalledMediaClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesMediaManagerCreateInstallerMediaForPathData BoxesMediaManagerCreateInstallerMediaForPathData;

#define BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA (boxes_libvirt_system_media_get_type ())
#define BOXES_LIBVIRT_SYSTEM_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA, BoxesLibvirtSystemMedia))
#define BOXES_LIBVIRT_SYSTEM_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA, BoxesLibvirtSystemMediaClass))
#define BOXES_IS_LIBVIRT_SYSTEM_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA))
#define BOXES_IS_LIBVIRT_SYSTEM_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA))
#define BOXES_LIBVIRT_SYSTEM_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_MEDIA, BoxesLibvirtSystemMediaClass))

typedef struct _BoxesLibvirtSystemMedia BoxesLibvirtSystemMedia;
typedef struct _BoxesLibvirtSystemMediaClass BoxesLibvirtSystemMediaClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaFromConfigData BoxesMediaManagerCreateInstallerMediaFromConfigData;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_TRACKER_ISO_QUERY (boxes_tracker_iso_query_get_type ())
#define BOXES_TRACKER_ISO_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQuery))
#define BOXES_TRACKER_ISO_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQueryClass))
#define BOXES_IS_TRACKER_ISO_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TRACKER_ISO_QUERY))
#define BOXES_IS_TRACKER_ISO_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TRACKER_ISO_QUERY))
#define BOXES_TRACKER_ISO_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQueryClass))

typedef struct _BoxesTrackerISOQuery BoxesTrackerISOQuery;
typedef struct _BoxesTrackerISOQueryClass BoxesTrackerISOQueryClass;
#define _boxes_tracker_iso_query_unref0(var) ((var == NULL) ? NULL : (var = (boxes_tracker_iso_query_unref (var), NULL)))
typedef struct _BoxesMediaManagerListInstallerMediasData BoxesMediaManagerListInstallerMediasData;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData BoxesMediaManagerCreateInstallerMediaFromIsoInfoData;

struct _BoxesMediaManager {
	GObject parent_instance;
	BoxesMediaManagerPrivate * priv;
};

struct _BoxesMediaManagerClass {
	GObjectClass parent_class;
};

struct _BoxesMediaManagerPrivate {
	BoxesOSDatabase* _os_db;
	GUdevClient* _client;
	TrackerSparqlConnection* connection;
};

struct _BoxesMediaManagerCreateInstallerMediaForPathData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	GCancellable* cancellable;
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* media;
	BoxesInstalledMedia* _tmp0_;
	const gchar* _tmp1_;
	BoxesInstalledMedia* _tmp2_;
	BoxesInstalledMedia* _tmp3_;
	GError* e;
	BoxesInstallerMedia* _tmp4_;
	const gchar* _tmp5_;
	GCancellable* _tmp6_;
	BoxesInstallerMedia* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	BoxesInstallerMedia* _tmp9_;
	BoxesInstallerMedia* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	BoxesInstallerMedia* _tmp12_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesMediaManagerCreateInstallerMediaFromConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GVirConfigDomain* config;
	BoxesInstallerMedia* result;
	gchar* path;
	GVirConfigDomain* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	GVirConfigDomain* _tmp3_;
	gboolean _tmp4_;
	BoxesInstalledMedia* _tmp5_;
	const gchar* _tmp6_;
	BoxesInstalledMedia* _tmp7_;
	BoxesInstalledMedia* _tmp8_;
	GVirConfigDomain* _tmp9_;
	gboolean _tmp10_;
	BoxesLibvirtSystemMedia* _tmp11_;
	const gchar* _tmp12_;
	GVirConfigDomain* _tmp13_;
	BoxesLibvirtSystemMedia* _tmp14_;
	BoxesLibvirtSystemMedia* _tmp15_;
	GError* _error_;
	GError* _tmp16_;
	const gchar* _tmp17_;
	gchar* label;
	GVirConfigDomain* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	OsinfoOs* os;
	OsinfoMedia* os_media;
	gchar* os_id;
	GVirConfigDomain* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	OsinfoOs* _tmp25_;
	BoxesOSDatabase* _tmp26_;
	const gchar* _tmp27_;
	OsinfoOs* _tmp28_;
	OsinfoOs* _tmp29_;
	gchar* media_id;
	GVirConfigDomain* _tmp30_;
	gchar* _tmp31_;
	const gchar* _tmp32_;
	OsinfoMedia* _tmp33_;
	BoxesOSDatabase* _tmp34_;
	OsinfoOs* _tmp35_;
	const gchar* _tmp36_;
	OsinfoMedia* _tmp37_;
	OsinfoMedia* _tmp38_;
	GError* _vala1__error_;
	GError* _tmp39_;
	const gchar* _tmp40_;
	gchar* _tmp41_;
	OsinfoMedia* _tmp42_;
	OsinfoMedia* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* architecture;
	gchar* _tmp46_;
	OsinfoResources* resources;
	BoxesOSDatabase* _tmp47_;
	OsinfoOs* _tmp48_;
	const gchar* _tmp49_;
	OsinfoResources* _tmp50_;
	BoxesInstallerMedia* media;
	const gchar* _tmp51_;
	const gchar* _tmp52_;
	OsinfoOs* _tmp53_;
	OsinfoMedia* _tmp54_;
	OsinfoResources* _tmp55_;
	BoxesInstallerMedia* _tmp56_;
	BoxesInstallerMedia* _tmp57_;
	BoxesInstallerMedia* _tmp58_;
	BoxesInstallerMedia* _tmp59_;
	BoxesInstallerMedia* _tmp60_;
	BoxesInstallerMedia* _tmp61_;
	GError* _vala2__error_;
	GError* _tmp62_;
	const gchar* _tmp63_;
	GError * _inner_error_;
};

struct _BoxesMediaManagerListInstallerMediasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GList* result;
	GList* list;
	GUdevEnumerator* enumerator;
	GUdevClient* _tmp0_;
	GUdevEnumerator* _tmp1_;
	GUdevEnumerator* _tmp2_;
	GUdevEnumerator* _tmp3_;
	GList* _tmp4_;
	GList* device_collection;
	GList* device_it;
	GUdevDevice* _tmp5_;
	GUdevDevice* device;
	gboolean _tmp6_;
	gboolean _tmp7_;
	GUdevDevice* _tmp8_;
	const gchar* _tmp9_;
	GUdevDevice* _tmp10_;
	gboolean _tmp11_;
	GUdevDevice* _tmp12_;
	gboolean _tmp13_;
	gchar* path;
	GUdevDevice* _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	GFile* file;
	const gchar* _tmp17_;
	GFile* _tmp18_;
	GFileInfo* info;
	GFile* _tmp19_;
	GFileInfo* _tmp20_;
	GFileInfo* _tmp21_;
	gboolean _tmp22_;
	const gchar* _tmp23_;
	BoxesInstallerMedia* media;
	const gchar* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	BoxesInstallerMedia* _tmp26_;
	BoxesInstallerMedia* _tmp27_;
	GError* _error_;
	const gchar* _tmp28_;
	GError* _tmp29_;
	const gchar* _tmp30_;
	TrackerSparqlConnection* _tmp31_;
	BoxesTrackerISOQuery* query;
	TrackerSparqlConnection* _tmp32_;
	BoxesTrackerISOQuery* _tmp33_;
	gchar* _vala1_path;
	gchar* title;
	gchar* os_id;
	gchar* media_id;
	gchar** lang_list;
	gint lang_list_length1;
	gint _lang_list_size_;
	gboolean _tmp34_;
	BoxesTrackerISOQuery* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar** _tmp40_;
	gint _tmp41_;
	gboolean _tmp42_;
	BoxesInstallerMedia* _vala1_media;
	const gchar* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	const gchar* _tmp46_;
	gchar** _tmp47_;
	gint _tmp47__length1;
	BoxesInstallerMedia* _tmp48_;
	GList* dup_node;
	GList* _tmp49_;
	BoxesInstallerMedia* _tmp50_;
	GList* _tmp51_;
	GList* _tmp52_;
	BoxesInstallerMedia* dup_media;
	GList* _tmp53_;
	gconstpointer _tmp54_;
	BoxesInstallerMedia* _tmp55_;
	BoxesInstallerMedia* _tmp56_;
	BoxesInstallerMedia* _tmp57_;
	gint _tmp58_;
	BoxesInstallerMedia* _tmp59_;
	BoxesInstallerMedia* _tmp60_;
	BoxesInstallerMedia* _tmp61_;
	GError* _vala1__error_;
	const gchar* _tmp62_;
	GError* _tmp63_;
	const gchar* _tmp64_;
	GError* _vala2__error_;
	GError* _tmp65_;
	const gchar* _tmp66_;
	GError * _inner_error_;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	gchar* label;
	gchar* os_id;
	gchar* media_id;
	gchar** lang_list;
	gint lang_list_length1;
	BoxesInstallerMedia* result;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GError* _tmp6_;
	GError* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	BoxesInstallerMedia* _tmp15_;
	const gchar* _tmp16_;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	OsinfoOs* os;
	BoxesOSDatabase* _tmp19_;
	const gchar* _tmp20_;
	OsinfoOs* _tmp21_;
	OsinfoMedia* os_media;
	BoxesOSDatabase* _tmp22_;
	OsinfoOs* _tmp23_;
	const gchar* _tmp24_;
	OsinfoMedia* _tmp25_;
	gchar** _tmp26_;
	gint _tmp26__length1;
	gchar** lang_collection;
	gint lang_collection_length1;
	gint _lang_collection_size_;
	gint lang_it;
	gchar* _tmp27_;
	gchar* lang;
	OsinfoMedia* _tmp28_;
	const gchar* _tmp29_;
	OsinfoResources* resources;
	BoxesOSDatabase* _tmp30_;
	OsinfoOs* _tmp31_;
	OsinfoMedia* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	OsinfoResources* _tmp36_;
	OsinfoResources* _tmp37_;
	BoxesInstallerMedia* media;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	OsinfoOs* _tmp40_;
	OsinfoMedia* _tmp41_;
	OsinfoResources* _tmp42_;
	BoxesInstallerMedia* _tmp43_;
	BoxesInstallerMedia* _tmp44_;
	BoxesInstallerMedia* _tmp45_;
	BoxesInstallerMedia* _tmp46_;
	BoxesInstallerMedia* _tmp47_;
	GError * _inner_error_;
};

typedef void (*BoxesMediaManagerInstallerRecognized) (OsinfoMedia* os_media, OsinfoOs* os, void* user_data);

static gpointer boxes_media_manager_parent_class = NULL;
static BoxesMediaManager* boxes_media_manager_media_manager;
static BoxesMediaManager* boxes_media_manager_media_manager = NULL;

GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_os_database_get_type (void) G_GNUC_CONST;
#define BOXES_MEDIA_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerPrivate))
enum  {
	BOXES_MEDIA_MANAGER_DUMMY_PROPERTY,
	BOXES_MEDIA_MANAGER_OS_DB,
	BOXES_MEDIA_MANAGER_CLIENT
};
BoxesMediaManager* boxes_media_manager_get_instance (void);
static BoxesMediaManager* boxes_media_manager_new (void);
static BoxesMediaManager* boxes_media_manager_construct (GType object_type);
static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_);
GType boxes_installed_media_get_type (void) G_GNUC_CONST;
void boxes_installed_media_new_guess_os (const gchar* path, BoxesMediaManager* media_manager, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstalledMedia* boxes_installed_media_new_guess_os_finish (GAsyncResult* _res_, GError** error);
void boxes_installed_media_construct_guess_os (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstalledMedia* boxes_installed_media_construct_guess_os_finish (GAsyncResult* _res_, GError** error);
static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_installer_media_new_for_path (const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_new_for_path_finish (GAsyncResult* _res_, GError** error);
void boxes_installer_media_construct_for_path (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_construct_for_path_finish (GAsyncResult* _res_, GError** error);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_);
gchar* boxes_vm_configurator_get_source_media_path (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_import_config (GVirConfigDomain* domain);
static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gboolean boxes_vm_configurator_is_libvirt_system_import_config (GVirConfigDomain* domain);
GType boxes_libvirt_system_media_get_type (void) G_GNUC_CONST;
BoxesLibvirtSystemMedia* boxes_libvirt_system_media_new (const gchar* path, GVirConfigDomain* domain_config, GError** error);
BoxesLibvirtSystemMedia* boxes_libvirt_system_media_construct (GType object_type, const gchar* path, GVirConfigDomain* domain_config, GError** error);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
gchar* boxes_vm_configurator_get_os_media_id (GVirConfigDomain* domain);
OsinfoMedia* boxes_os_database_get_media_by_id (BoxesOSDatabase* self, OsinfoOs* os, const gchar* id, GError** error);
OsinfoResources* boxes_os_database_get_resources_for_os (BoxesOSDatabase* self, OsinfoOs* os, const gchar* architecture);
BoxesInstallerMedia* boxes_installer_media_new_from_iso_info (const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
BoxesInstallerMedia* boxes_installer_media_construct_from_iso_info (GType object_type, const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_media_manager_list_installer_medias_data_free (gpointer _data);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_);
GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self);
static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gpointer boxes_tracker_iso_query_ref (gpointer instance);
void boxes_tracker_iso_query_unref (gpointer instance);
GParamSpec* boxes_param_spec_tracker_iso_query (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_tracker_iso_query (GValue* value, gpointer v_object);
void boxes_value_take_tracker_iso_query (GValue* value, gpointer v_object);
gpointer boxes_value_get_tracker_iso_query (const GValue* value);
GType boxes_tracker_iso_query_get_type (void) G_GNUC_CONST;
void boxes_tracker_iso_query_new (TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesTrackerISOQuery* boxes_tracker_iso_query_new_finish (GAsyncResult* _res_, GError** error);
void boxes_tracker_iso_query_construct (GType object_type, TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesTrackerISOQuery* boxes_tracker_iso_query_construct_finish (GAsyncResult* _res_, GError** error);
void boxes_tracker_iso_query_fetch_next_iso_data (BoxesTrackerISOQuery* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_tracker_iso_query_fetch_next_iso_data_finish (BoxesTrackerISOQuery* self, GAsyncResult* _res_, gchar** path, gchar** title, gchar** os_id, gchar** media_id, gchar*** lang_list, int* lang_list_length1, GError** error);
static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, gchar** lang_list, int lang_list_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gint boxes_media_manager_compare_media_by_label (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b);
static gint _boxes_media_manager_compare_media_by_label_gcompare_func (gconstpointer a, gconstpointer b);
static gint boxes_media_manager_compare_media_by_release_date (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value);
BoxesOSDatabase* boxes_os_database_new (void);
BoxesOSDatabase* boxes_os_database_construct (GType object_type);
static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value);
void boxes_os_database_load (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_os_database_load_finish (BoxesOSDatabase* self, GAsyncResult* _res_);
static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data);
static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_);
static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_media_manager_finalize (GObject* obj);
static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return self ? g_object_ref (self) : NULL;
#line 569 "media-manager.c"
}


BoxesMediaManager* boxes_media_manager_get_instance (void) {
	BoxesMediaManager* result = NULL;
	BoxesMediaManager* _tmp0_ = NULL;
	BoxesMediaManager* _tmp2_ = NULL;
	BoxesMediaManager* _tmp3_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = boxes_media_manager_media_manager;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp0_ == NULL) {
#line 582 "media-manager.c"
		BoxesMediaManager* _tmp1_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp1_ = boxes_media_manager_new ();
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (boxes_media_manager_media_manager);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_media_manager = _tmp1_;
#line 590 "media-manager.c"
	}
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = boxes_media_manager_media_manager;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp3_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 600 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaForPathData, _data_);
#line 617 "media-manager.c"
}


void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaForPathData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_for_path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_for_path_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = cancellable;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->cancellable = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 656 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 667 "media-manager.c"
	}
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 677 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 691 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 700 "media-manager.c"
		goto _state_0;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 704 "media-manager.c"
		goto _state_1;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 708 "media-manager.c"
		goto _state_2;
		default:
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 713 "media-manager.c"
	}
	_state_0:
	{
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp1_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp1_ = _data_->path;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 1;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_installed_media_new_guess_os (_data_->_tmp1_, _data_->self, boxes_media_manager_create_installer_media_for_path_ready, _data_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 727 "media-manager.c"
		_state_1:
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = boxes_installed_media_new_guess_os_finish (_data_->_res_, &_data_->_inner_error_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp0_ = _data_->_tmp2_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED)) {
#line 739 "media-manager.c"
				goto __catch55_g_io_error_not_supported;
			}
			goto __finally55;
		}
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->_tmp0_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp0_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = (BoxesInstallerMedia*) _data_->_tmp3_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 756 "media-manager.c"
	}
	goto __finally55;
	__catch55_g_io_error_not_supported:
	{
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->e = _data_->_inner_error_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = _data_->path;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = _data_->cancellable;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 2;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_installer_media_new_for_path (_data_->_tmp5_, _data_->self, _data_->_tmp6_, boxes_media_manager_create_installer_media_for_path_ready, _data_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 779 "media-manager.c"
		_state_2:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = boxes_installer_media_new_for_path_finish (_data_->_res_, &_data_->_inner_error_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = _data_->_tmp7_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_error_free0 (_data_->e);
#line 791 "media-manager.c"
			goto __finally55;
		}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = _data_->_tmp4_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = _data_->_tmp8_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->e);
#line 808 "media-manager.c"
	}
	__finally55:
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 823 "media-manager.c"
		} else {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 827 "media-manager.c"
		}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 833 "media-manager.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = _data_->media;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp10_, &_data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp9_ = _data_->_tmp11_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 857 "media-manager.c"
		} else {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 861 "media-manager.c"
		}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 867 "media-manager.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = _data_->_tmp9_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp9_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp12_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->_tmp9_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 885 "media-manager.c"
	} else {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 889 "media-manager.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->_tmp9_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 903 "media-manager.c"
	} else {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 907 "media-manager.c"
	}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 913 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromConfigData, _data_);
#line 928 "media-manager.c"
}


void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromConfigData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_config);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_config_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = config;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->config = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 957 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 972 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 986 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 995 "media-manager.c"
		goto _state_0;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 999 "media-manager.c"
		goto _state_1;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 1003 "media-manager.c"
		goto _state_2;
		default:
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 1008 "media-manager.c"
	}
	_state_0:
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->config;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = boxes_vm_configurator_get_source_media_path (_data_->_tmp0_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _data_->_tmp1_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->path;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp2_ == NULL) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1035 "media-manager.c"
		} else {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1039 "media-manager.c"
		}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1045 "media-manager.c"
	}
	{
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->config;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = FALSE;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = boxes_vm_configurator_is_import_config (_data_->_tmp3_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_tmp4_) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp6_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp6_ = _data_->path;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 1;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			boxes_installed_media_new_guess_os (_data_->_tmp6_, _data_->self, boxes_media_manager_create_installer_media_from_config_ready, _data_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1068 "media-manager.c"
			_state_1:
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp7_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp7_ = boxes_installed_media_new_guess_os_finish (_data_->_res_, &_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1078 "media-manager.c"
				goto __catch56_g_error;
			}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp8_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp8_ = _data_->_tmp5_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->result = (BoxesInstallerMedia*) _data_->_tmp8_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->_tmp5_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->path);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1097 "media-manager.c"
			} else {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1101 "media-manager.c"
			}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1107 "media-manager.c"
		} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp9_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp9_ = _data_->config;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp10_ = FALSE;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp10_ = boxes_vm_configurator_is_libvirt_system_import_config (_data_->_tmp9_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp10_) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp12_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp12_ = _data_->path;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = _data_->config;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = boxes_libvirt_system_media_new (_data_->_tmp12_, _data_->_tmp13_, &_data_->_inner_error_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp11_ = _data_->_tmp14_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1135 "media-manager.c"
					goto __catch56_g_error;
				}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp15_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp15_ = _data_->_tmp11_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp11_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->result = (BoxesInstallerMedia*) _data_->_tmp15_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->_tmp11_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_state_ == 0) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1154 "media-manager.c"
				} else {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1158 "media-manager.c"
				}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_object_unref (_data_->_async_result);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 1164 "media-manager.c"
			}
		}
	}
	goto __finally56;
	__catch56_g_error:
	{
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = _data_->_error_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = _data_->_tmp16_->message;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_debug ("media-manager.vala:48: %s", _data_->_tmp17_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1195 "media-manager.c"
		} else {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1199 "media-manager.c"
		}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1205 "media-manager.c"
	}
	__finally56:
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1218 "media-manager.c"
	}
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp18_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp18_ = _data_->config;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = gvir_config_domain_get_title (_data_->_tmp18_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->label = _data_->_tmp21_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_media = NULL;
#line 1242 "media-manager.c"
	{
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp22_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp22_ = _data_->config;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = boxes_vm_configurator_get_os_id (_data_->_tmp22_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->os_id = _data_->_tmp23_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = _data_->os_id;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_tmp24_ != NULL) {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = _data_->self->priv->_os_db;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = _data_->os_id;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 2;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			boxes_os_database_get_os_by_id (_data_->_tmp26_, _data_->_tmp27_, boxes_media_manager_create_installer_media_from_config_ready, _data_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1274 "media-manager.c"
			_state_2:
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp28_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp28_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp26_, _data_->_res_, &_data_->_inner_error_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp25_ = _data_->_tmp28_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 1288 "media-manager.c"
					goto __catch57_boxes_os_database_error;
				}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->label);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_clear_error (&_data_->_inner_error_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 1307 "media-manager.c"
			}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = _data_->_tmp25_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp25_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->os);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->os = _data_->_tmp29_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = _data_->config;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp31_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp31_ = boxes_vm_configurator_get_os_media_id (_data_->_tmp30_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp31_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = _data_->media_id;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp32_ != NULL) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp34_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp34_ = _data_->self->priv->_os_db;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp35_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp35_ = _data_->os;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp36_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp36_ = _data_->media_id;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp37_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp37_ = boxes_os_database_get_media_by_id (_data_->_tmp34_, _data_->_tmp35_, _data_->_tmp36_, &_data_->_inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp33_ = _data_->_tmp37_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->_tmp25_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 1363 "media-manager.c"
						goto __catch57_boxes_os_database_error;
					}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->_tmp25_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os_media);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->label);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1386 "media-manager.c"
				}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp38_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp38_ = _data_->_tmp33_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp33_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->os_media = _data_->_tmp38_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->_tmp33_);
#line 1400 "media-manager.c"
			}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->_tmp25_);
#line 1406 "media-manager.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->os_id);
#line 1410 "media-manager.c"
	}
	goto __finally57;
	__catch57_boxes_os_database_error:
	{
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp39_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp39_ = _data_->_vala1__error_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp40_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp40_ = _data_->_tmp39_->message;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:68: %s", _data_->_tmp40_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 1431 "media-manager.c"
	}
	__finally57:
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1450 "media-manager.c"
	}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = _data_->os_media;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp42_ != NULL) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp43_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp43_ = _data_->os_media;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp44_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_get (_data_->_tmp43_, "architecture", &_data_->_tmp44_, NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp45_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp41_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp41_ = _data_->_tmp45_;
#line 1474 "media-manager.c"
	} else {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp41_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp41_ = NULL;
#line 1480 "media-manager.c"
	}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = g_strdup (_data_->_tmp41_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->architecture = _data_->_tmp46_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = _data_->self->priv->_os_db;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp48_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp48_ = _data_->os;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp49_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp49_ = _data_->architecture;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp50_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp50_ = boxes_os_database_get_resources_for_os (_data_->_tmp47_, _data_->_tmp48_, _data_->_tmp49_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp50_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp51_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp51_ = _data_->path;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp52_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp52_ = _data_->label;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp53_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp53_ = _data_->os;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp54_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp54_ = _data_->os_media;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp55_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp55_ = _data_->resources;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp56_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp56_ = boxes_installer_media_new_from_iso_info (_data_->_tmp51_, _data_->_tmp52_, _data_->_tmp53_, _data_->_tmp54_, _data_->_tmp55_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp56_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp57_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp57_ = _data_->media;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (_data_->_tmp57_ != NULL, NULL);
#line 1538 "media-manager.c"
	{
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp59_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp59_ = _data_->media;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp60_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp60_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp59_, &_data_->_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp58_ = _data_->_tmp60_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1552 "media-manager.c"
			goto __catch58_g_error;
		}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp61_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp61_ = _data_->_tmp58_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp58_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = _data_->_tmp61_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->_tmp58_);
#line 1567 "media-manager.c"
	}
	goto __finally58;
	__catch58_g_error:
	{
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp62_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp62_ = _data_->_vala2__error_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp63_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp63_ = _data_->_tmp62_->message;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_debug ("media-manager.vala:80: %s", _data_->_tmp63_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 1588 "media-manager.c"
	}
	__finally58:
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->architecture);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp41_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1615 "media-manager.c"
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->media;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp41_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1637 "media-manager.c"
	} else {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1641 "media-manager.c"
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp41_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1667 "media-manager.c"
	} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1671 "media-manager.c"
	}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 1677 "media-manager.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1684 "media-manager.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_list_free (self);
#line 1693 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_data_free (gpointer _data) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->result);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerListInstallerMediasData, _data_);
#line 1706 "media-manager.c"
}


void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerListInstallerMediasData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_list_installer_medias);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_list_installer_medias_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1725 "media-manager.c"
}


GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	GList* result;
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 1740 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1754 "media-manager.c"
}


static gint _boxes_media_manager_compare_media_by_label_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = boxes_media_manager_compare_media_by_label ((BoxesInstallerMedia*) a, (BoxesInstallerMedia*) b);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 1763 "media-manager.c"
}


static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 1772 "media-manager.c"
		goto _state_0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 1776 "media-manager.c"
		goto _state_1;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 1780 "media-manager.c"
		goto _state_2;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 3:
#line 1784 "media-manager.c"
		goto _state_3;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 4:
#line 1788 "media-manager.c"
		goto _state_4;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 5:
#line 1792 "media-manager.c"
		goto _state_5;
		default:
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 1797 "media-manager.c"
	}
	_state_0:
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->list = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->self->priv->_client;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_udev_enumerator_new (_data_->_tmp0_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->enumerator = _data_->_tmp1_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->enumerator;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_udev_enumerator_add_match_property (_data_->_tmp2_, "DEVTYPE", "disk");
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = _data_->enumerator;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = g_udev_enumerator_execute (_data_->_tmp3_);
#line 1826 "media-manager.c"
	{
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->device_collection = _data_->_tmp4_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		for (_data_->device_it = _data_->device_collection; _data_->device_it != NULL; _data_->device_it = _data_->device_it->next) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = _g_object_ref0 ((GUdevDevice*) _data_->device_it->data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->device = _data_->_tmp5_;
#line 1838 "media-manager.c"
			{
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = _data_->device;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp9_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp9_ = g_udev_device_get_property (_data_->_tmp8_, "ID_FS_BOOT_SYSTEM_ID");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp9_ == NULL) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = _data_->device;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp11_ = FALSE;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp11_ = g_udev_device_get_property_as_boolean (_data_->_tmp10_, "OSINFO_BOOTABLE");
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp7_ = !_data_->_tmp11_;
#line 1860 "media-manager.c"
				} else {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp7_ = FALSE;
#line 1864 "media-manager.c"
				}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp7_) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = TRUE;
#line 1870 "media-manager.c"
				} else {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp12_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp12_ = _data_->device;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp13_ = FALSE;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp13_ = g_udev_device_get_property_as_boolean (_data_->_tmp12_, "ID_CDROM");
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = _data_->_tmp13_;
#line 1882 "media-manager.c"
				}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp6_) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					continue;
#line 1890 "media-manager.c"
				}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = _data_->device;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp15_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp15_ = g_udev_device_get_device_file (_data_->_tmp14_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp16_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp16_ = g_strdup (_data_->_tmp15_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->path = _data_->_tmp16_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp17_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp17_ = _data_->path;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp18_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp18_ = g_file_new_for_path (_data_->_tmp17_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->file = _data_->_tmp18_;
#line 1916 "media-manager.c"
				{
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp19_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp19_ = _data_->file;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_state_ = 1;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_file_query_info_async (_data_->_tmp19_, G_FILE_ATTRIBUTE_ACCESS_CAN_READ, G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1928 "media-manager.c"
					_state_1:
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp20_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp20_ = g_file_query_info_finish (_data_->_tmp19_, _data_->_res_, &_data_->_inner_error_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->info = _data_->_tmp20_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1938 "media-manager.c"
						goto __catch59_g_error;
					}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp21_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp21_ = _data_->info;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp22_ = FALSE;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp22_ = g_file_info_get_attribute_boolean (_data_->_tmp21_, G_FILE_ATTRIBUTE_ACCESS_CAN_READ);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (!_data_->_tmp22_) {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_data_->_tmp23_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_data_->_tmp23_ = _data_->path;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						g_debug ("media-manager.vala:108: No read access to '%s', ignoring..", _data_->_tmp23_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->info);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->file);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_free0 (_data_->path);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->device);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						continue;
#line 1967 "media-manager.c"
					}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp24_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp24_ = _data_->path;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_state_ = 2;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp24_, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1979 "media-manager.c"
					_state_2:
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp25_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp25_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->media = _data_->_tmp25_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->info);
#line 1991 "media-manager.c"
						goto __catch59_g_error;
					}
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp26_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp26_ = _data_->media;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp27_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp27_ = _g_object_ref0 (_data_->_tmp26_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->list = g_list_append (_data_->list, _data_->_tmp27_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->media);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->info);
#line 2008 "media-manager.c"
				}
				goto __finally59;
				__catch59_g_error:
				{
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_inner_error_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp28_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp28_ = _data_->path;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp29_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp29_ = _data_->_error_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp30_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp30_ = _data_->_tmp29_->message;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_warning ("media-manager.vala:116: Failed to get information on device '%s': %s. " \
"Ignoring..", _data_->_tmp28_, _data_->_tmp30_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_error_free0 (_data_->_error_);
#line 2033 "media-manager.c"
				}
				__finally59:
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->file);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->enumerator);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->list);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 2056 "media-manager.c"
				}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->file);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->device);
#line 2064 "media-manager.c"
			}
		}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 2069 "media-manager.c"
	}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = _data_->self->priv->connection;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp31_ == NULL) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->list;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2085 "media-manager.c"
		} else {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2089 "media-manager.c"
		}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2095 "media-manager.c"
	}
	{
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp32_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp32_ = _data_->self->priv->connection;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 3;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_tracker_iso_query_new (_data_->_tmp32_, boxes_media_manager_list_installer_medias_ready, _data_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2108 "media-manager.c"
		_state_3:
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp33_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp33_ = boxes_tracker_iso_query_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->query = _data_->_tmp33_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2118 "media-manager.c"
			goto __catch60_g_error;
		}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->lang_list_length1 = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_lang_list_size_ = 0;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		while (TRUE) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = _data_->query;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp36_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp37_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp38_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp39_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp40_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp41_ = 0;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 4;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			boxes_tracker_iso_query_fetch_next_iso_data (_data_->_tmp35_, boxes_media_manager_list_installer_medias_ready, _data_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 2149 "media-manager.c"
			_state_4:
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp42_ = FALSE;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp42_ = boxes_tracker_iso_query_fetch_next_iso_data_finish (_data_->_tmp35_, _data_->_res_, &_data_->_tmp36_, &_data_->_tmp37_, &_data_->_tmp38_, &_data_->_tmp39_, &_data_->_tmp40_, &_data_->_tmp41_, &_data_->_inner_error_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->_vala1_path);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_vala1_path = _data_->_tmp36_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->title);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->title = _data_->_tmp37_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->os_id);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->os_id = _data_->_tmp38_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp39_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->lang_list = _data_->_tmp40_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->lang_list_length1 = _data_->_tmp41_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_lang_list_size_ = _data_->lang_list_length1;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp34_ = _data_->_tmp42_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->media_id);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->title);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_boxes_tracker_iso_query_unref0 (_data_->query);
#line 2195 "media-manager.c"
				goto __catch60_g_error;
			}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (!_data_->_tmp34_) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				break;
#line 2202 "media-manager.c"
			}
			{
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp43_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp43_ = _data_->_vala1_path;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp44_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp44_ = _data_->title;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp45_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp45_ = _data_->os_id;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp46_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp46_ = _data_->media_id;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47__length1 = 0;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = _data_->lang_list;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47__length1 = _data_->lang_list_length1;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_state_ = 5;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				boxes_media_manager_create_installer_media_from_iso_info (_data_->self, _data_->_tmp43_, _data_->_tmp44_, _data_->_tmp45_, _data_->_tmp46_, _data_->_tmp47_, _data_->_tmp47__length1, boxes_media_manager_list_installer_medias_ready, _data_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 2235 "media-manager.c"
				_state_5:
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp48_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp48_ = boxes_media_manager_create_installer_media_from_iso_info_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_vala1_media = _data_->_tmp48_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2245 "media-manager.c"
					goto __catch61_g_error;
				}
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp49_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp49_ = _data_->list;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp50_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp50_ = _data_->_vala1_media;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp51_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp51_ = g_list_find_custom (_data_->_tmp49_, _data_->_tmp50_, _boxes_media_manager_compare_media_by_label_gcompare_func);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->dup_node = _data_->_tmp51_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp52_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp52_ = _data_->dup_node;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp52_ != NULL) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp53_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp53_ = _data_->dup_node;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp54_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp54_ = _data_->_tmp53_->data;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp55_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp55_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_tmp54_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->dup_media = _data_->_tmp55_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp56_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp56_ = _data_->_vala1_media;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp57_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp57_ = _data_->dup_media;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp58_ = 0;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp58_ = boxes_media_manager_compare_media_by_release_date (_data_->_tmp56_, _data_->_tmp57_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (_data_->_tmp58_ <= 0) {
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_data_->_tmp59_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_data_->_tmp59_ = _data_->dup_media;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_data_->list = g_list_remove (_data_->list, _data_->_tmp59_);
#line 2302 "media-manager.c"
					} else {
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->dup_media);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						_g_object_unref0 (_data_->_vala1_media);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
						continue;
#line 2310 "media-manager.c"
					}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->dup_media);
#line 2314 "media-manager.c"
				}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp60_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp60_ = _data_->_vala1_media;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp61_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp61_ = _g_object_ref0 (_data_->_tmp60_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->list = g_list_insert_sorted (_data_->list, _data_->_tmp61_, _boxes_media_manager_compare_media_by_label_gcompare_func);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 2328 "media-manager.c"
			}
			goto __finally61;
			__catch61_g_error:
			{
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_inner_error_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp62_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp62_ = _data_->_vala1_path;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp63_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp63_ = _data_->_vala1__error_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp64_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp64_ = _data_->_tmp63_->message;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_warning ("media-manager.vala:151: Failed to use ISO '%s': %s", _data_->_tmp62_, _data_->_tmp64_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 2353 "media-manager.c"
			}
			__finally61:
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->media_id);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->title);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_boxes_tracker_iso_query_unref0 (_data_->query);
#line 2370 "media-manager.c"
				goto __catch60_g_error;
			}
		}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->media_id);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->os_id);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->title);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_vala1_path);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_boxes_tracker_iso_query_unref0 (_data_->query);
#line 2386 "media-manager.c"
	}
	goto __finally60;
	__catch60_g_error:
	{
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp65_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp65_ = _data_->_vala2__error_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp66_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp66_ = _data_->_tmp65_->message;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:155: Failed to fetch list of ISOs from Tracker: %s.", _data_->_tmp66_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 2407 "media-manager.c"
	}
	__finally60:
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->list);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2422 "media-manager.c"
	}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->list;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2432 "media-manager.c"
	} else {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2436 "media-manager.c"
	}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->list);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2450 "media-manager.c"
	} else {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2454 "media-manager.c"
	}
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2460 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error) {
	BoxesInstallerMedia* result = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
	OsinfoInstallScriptList* install_scripts = NULL;
	BoxesInstallerMedia* _tmp4_ = NULL;
	OsinfoOs* _tmp5_ = NULL;
	OsinfoInstallScriptList* _tmp6_ = NULL;
	OsinfoFilter* filter = NULL;
	OsinfoFilter* _tmp7_ = NULL;
	OsinfoFilter* _tmp8_ = NULL;
	OsinfoInstallScriptList* _tmp9_ = NULL;
	OsinfoFilter* _tmp10_ = NULL;
	OsinfoList* _tmp11_ = NULL;
	OsinfoInstallScriptList* _tmp12_ = NULL;
	BoxesInstallerMedia* install_media = NULL;
	BoxesInstallerMedia* _tmp13_ = NULL;
	BoxesInstallerMedia* _tmp14_ = NULL;
	OsinfoInstallScriptList* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	GError * _inner_error_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = media;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _tmp0_->os;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp1_ == NULL) {
#line 2495 "media-manager.c"
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp2_ = media;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		result = _tmp3_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return result;
#line 2506 "media-manager.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = media;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp4_->os;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = osinfo_os_get_install_script_list (_tmp5_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp6_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = osinfo_filter_new ();
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	filter = _tmp7_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp8_ = filter;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	osinfo_filter_add_constraint (_tmp8_, OSINFO_INSTALL_SCRIPT_PROP_PROFILE, OSINFO_INSTALL_SCRIPT_PROFILE_DESKTOP);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp9_ = install_scripts;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp10_ = filter;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp11_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp9_) : NULL, _tmp10_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, osinfo_install_scriptlist_get_type ()) ? ((OsinfoInstallScriptList*) _tmp11_) : NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp12_ == NULL) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_tmp11_);
#line 2536 "media-manager.c"
	}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp12_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp13_ = media;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	install_media = _tmp14_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp15_ = install_scripts;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp16_ = osinfo_list_get_length ((OsinfoList*) _tmp15_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp16_ > 0) {
#line 2554 "media-manager.c"
		{
			BoxesUnattendedInstaller* _tmp17_ = NULL;
			BoxesInstallerMedia* _tmp18_ = NULL;
			OsinfoInstallScriptList* _tmp19_ = NULL;
			BoxesUnattendedInstaller* _tmp20_ = NULL;
			BoxesUnattendedInstaller* _tmp21_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp18_ = media;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp19_ = install_scripts;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp20_ = boxes_unattended_installer_new_from_media (_tmp18_, _tmp19_, &_inner_error_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp17_ = _tmp20_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED)) {
#line 2573 "media-manager.c"
					goto __catch62_g_io_error_not_supported;
				}
				goto __finally62;
			}
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp21_ = _tmp17_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp17_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_media);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			install_media = (BoxesInstallerMedia*) _tmp21_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_tmp17_);
#line 2588 "media-manager.c"
		}
		goto __finally62;
		__catch62_g_io_error_not_supported:
		{
			GError* e = NULL;
			GError* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			e = _inner_error_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_inner_error_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp22_ = e;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp23_ = _tmp22_->message;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_debug ("media-manager.vala:175: Unattended installer setup failed: %s", _tmp23_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_error_free0 (e);
#line 2608 "media-manager.c"
		}
		__finally62:
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_propagate_error (error, _inner_error_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_media);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (filter);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_scripts);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return NULL;
#line 2623 "media-manager.c"
		}
	}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = install_media;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (filter);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2634 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_construct (GType object_type) {
	BoxesMediaManager * self = NULL;
	gchar* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	GUdevClient* _tmp3_ = NULL;
	GUdevClient* _tmp4_ = NULL;
	BoxesOSDatabase* _tmp5_ = NULL;
	BoxesOSDatabase* _tmp6_ = NULL;
	BoxesOSDatabase* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self = (BoxesMediaManager*) g_object_new (object_type, NULL);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strdup ("block");
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = g_new0 (gchar*, 1 + 1);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_[0] = _tmp0_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2__length1 = 1;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = g_udev_client_new (_tmp2_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_client (self, _tmp4_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp4_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = (_vala_array_free (_tmp2_, _tmp2__length1, (GDestroyNotify) g_free), NULL);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = boxes_os_database_new ();
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = _tmp5_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_os_db (self, _tmp6_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp6_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = self->priv->_os_db;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_os_database_load (_tmp7_, NULL, NULL);
#line 2684 "media-manager.c"
	{
		TrackerSparqlConnection* _tmp8_ = NULL;
		TrackerSparqlConnection* _tmp9_ = NULL;
		TrackerSparqlConnection* _tmp10_ = NULL;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp9_ = tracker_sparql_connection_get (NULL, &_inner_error_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp8_ = _tmp9_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2695 "media-manager.c"
			goto __catch63_g_error;
		}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp10_ = _tmp8_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp8_ = NULL;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (self->priv->connection);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		self->priv->connection = _tmp10_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_tmp8_);
#line 2708 "media-manager.c"
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_error_ = _inner_error_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_inner_error_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp11_ = _error_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp12_ = _tmp11_->message;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("media-manager.vala:189: Error connecting to Tracker: %s", _tmp12_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_error_);
#line 2728 "media-manager.c"
	}
	__finally63:
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_inner_error_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 2739 "media-manager.c"
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return self;
#line 2743 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_new (void) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return boxes_media_manager_construct (BOXES_TYPE_MEDIA_MANAGER);
#line 2750 "media-manager.c"
}


static gint boxes_media_manager_compare_media_by_label (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b) {
	gint result = 0;
	GCompareFunc _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_a != NULL, 0);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_b != NULL, 0);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strcmp0;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = media_a;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_->label;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = media_b;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_->label;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp0_ (_tmp2_, _tmp4_);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp5_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2782 "media-manager.c"
}


static gint boxes_media_manager_compare_media_by_release_date (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b) {
	gint result = 0;
	BoxesInstallerMedia* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_a != NULL, 0);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_b != NULL, 0);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = media_a;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _tmp0_->os;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp1_ == NULL) {
#line 2800 "media-manager.c"
		BoxesInstallerMedia* _tmp2_ = NULL;
		OsinfoOs* _tmp3_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp2_ = media_b;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp3_ = _tmp2_->os;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_tmp3_ == NULL) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			result = 0;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return result;
#line 2813 "media-manager.c"
		} else {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			result = 1;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return result;
#line 2819 "media-manager.c"
		}
	} else {
		BoxesInstallerMedia* _tmp4_ = NULL;
		OsinfoOs* _tmp5_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp4_ = media_b;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp5_ = _tmp4_->os;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_tmp5_ == NULL) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			result = -1;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return result;
#line 2834 "media-manager.c"
		} else {
			GDate* release_a = NULL;
			BoxesInstallerMedia* _tmp6_ = NULL;
			OsinfoOs* _tmp7_ = NULL;
			GDate* _tmp8_ = NULL;
			GDate* release_b = NULL;
			BoxesInstallerMedia* _tmp9_ = NULL;
			OsinfoOs* _tmp10_ = NULL;
			GDate* _tmp11_ = NULL;
			GDate* _tmp12_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp6_ = media_a;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp7_ = _tmp6_->os;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp8_ = osinfo_product_get_release_date ((OsinfoProduct*) _tmp7_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			release_a = _tmp8_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp9_ = media_b;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp10_ = _tmp9_->os;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp11_ = osinfo_product_get_release_date ((OsinfoProduct*) _tmp10_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			release_b = _tmp11_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_tmp12_ = release_a;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_tmp12_ == NULL) {
#line 2865 "media-manager.c"
				GDate* _tmp13_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_tmp13_ = release_b;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_tmp13_ == NULL) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					result = 0;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_b);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_a);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return result;
#line 2879 "media-manager.c"
				} else {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					result = 1;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_b);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_a);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return result;
#line 2889 "media-manager.c"
				}
			} else {
				GDate* _tmp14_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_tmp14_ = release_b;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_tmp14_ == NULL) {
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					result = -1;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_b);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_a);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return result;
#line 2905 "media-manager.c"
				} else {
					GDate* _tmp15_ = NULL;
					GDate* _tmp16_ = NULL;
					GDate _tmp17_ = {0};
					gint _tmp18_ = 0;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_tmp15_ = release_a;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_tmp16_ = release_b;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_tmp17_ = *_tmp16_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_tmp18_ = g_date_compare (_tmp15_, &_tmp17_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					result = _tmp18_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_b);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (release_a);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return result;
#line 2927 "media-manager.c"
				}
			}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (release_b);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (release_a);
#line 2934 "media-manager.c"
		}
	}
}


static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData, _data_);
#line 2957 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, gchar** lang_list, int lang_list_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_iso_info);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_iso_info_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = label;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->label = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = os_id;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_id = _tmp6_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = media_id;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media_id = _tmp8_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp9_ = lang_list;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp9__length1 = lang_list_length1;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->lang_list = _tmp9_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->lang_list_length1 = _tmp9__length1;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 3026 "media-manager.c"
}


static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 3037 "media-manager.c"
	}
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 3047 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 3061 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 3070 "media-manager.c"
		goto _state_0;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 3074 "media-manager.c"
		goto _state_1;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 3078 "media-manager.c"
		goto _state_2;
		default:
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 3083 "media-manager.c"
	}
	_state_0:
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->path;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = FALSE;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_file_test (_data_->_tmp0_, G_FILE_TEST_EXISTS);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (!_data_->_tmp1_) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = _ ("No such file %s");
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->path;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = g_strdup_printf (_data_->_tmp2_, _data_->_tmp3_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _data_->_tmp5_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp5_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = _data_->_tmp7_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3132 "media-manager.c"
		} else {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3136 "media-manager.c"
		}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3142 "media-manager.c"
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = _data_->label;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp11_ == NULL) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp10_ = TRUE;
#line 3152 "media-manager.c"
	} else {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp12_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp12_ = _data_->os_id;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp10_ = _data_->_tmp12_ == NULL;
#line 3160 "media-manager.c"
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp10_) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = TRUE;
#line 3166 "media-manager.c"
	} else {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp13_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp13_ = _data_->media_id;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = _data_->_tmp13_ == NULL;
#line 3174 "media-manager.c"
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp9_) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = TRUE;
#line 3180 "media-manager.c"
	} else {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14__length1 = 0;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14_ = _data_->lang_list;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14__length1 = _data_->lang_list_length1;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = _data_->_tmp14_ == NULL;
#line 3192 "media-manager.c"
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp8_) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = _data_->path;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 1;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp16_, NULL, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3206 "media-manager.c"
		_state_1:
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = _data_->_tmp17_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_error_free (_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3224 "media-manager.c"
			} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3228 "media-manager.c"
			}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 3234 "media-manager.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp18_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp18_ = _data_->_tmp15_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->_tmp18_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->_tmp15_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3250 "media-manager.c"
		} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3254 "media-manager.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3260 "media-manager.c"
	}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = _data_->self->priv->_os_db;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = _data_->os_id;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_state_ = 2;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_os_database_get_os_by_id (_data_->_tmp19_, _data_->_tmp20_, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 3276 "media-manager.c"
	_state_2:
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp19_, _data_->_res_, &_data_->_inner_error_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os = _data_->_tmp21_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3294 "media-manager.c"
		} else {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3298 "media-manager.c"
		}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3304 "media-manager.c"
	}
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = _data_->self->priv->_os_db;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp23_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp23_ = _data_->os;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = _data_->media_id;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = boxes_os_database_get_media_by_id (_data_->_tmp22_, _data_->_tmp23_, _data_->_tmp24_, &_data_->_inner_error_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_media = _data_->_tmp25_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3336 "media-manager.c"
		} else {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3340 "media-manager.c"
		}
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3346 "media-manager.c"
	}
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26__length1 = 0;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26_ = _data_->lang_list;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26__length1 = _data_->lang_list_length1;
#line 3356 "media-manager.c"
	{
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->lang_collection_length1 = 0;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_lang_collection_size_ = 0;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->lang_collection = _data_->_tmp26_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->lang_collection_length1 = _data_->_tmp26__length1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		for (_data_->lang_it = 0; _data_->lang_it < _data_->_tmp26__length1; _data_->lang_it = _data_->lang_it + 1) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = g_strdup (_data_->lang_collection[_data_->lang_it]);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->lang = _data_->_tmp27_;
#line 3374 "media-manager.c"
			{
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp28_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp28_ = _data_->os_media;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp29_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp29_ = _data_->lang;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				osinfo_entity_add_param ((OsinfoEntity*) _data_->_tmp28_, OSINFO_MEDIA_PROP_LANG, _data_->_tmp29_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->lang);
#line 3388 "media-manager.c"
			}
		}
	}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = _data_->self->priv->_os_db;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = _data_->os;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = _data_->os_media;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp33_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_get (_data_->_tmp32_, "architecture", &_data_->_tmp33_, NULL);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = boxes_os_database_get_resources_for_os (_data_->_tmp30_, _data_->_tmp31_, _data_->_tmp35_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = _data_->_tmp36_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp35_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp37_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = _data_->path;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = _data_->label;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = _data_->os;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = _data_->os_media;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = _data_->resources;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp43_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp43_ = boxes_installer_media_new_from_iso_info (_data_->_tmp38_, _data_->_tmp39_, _data_->_tmp40_, _data_->_tmp41_, _data_->_tmp42_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp43_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp45_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp45_ = _data_->media;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp45_, &_data_->_inner_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp44_ = _data_->_tmp46_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3482 "media-manager.c"
		} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3486 "media-manager.c"
		}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 3492 "media-manager.c"
	}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = _data_->_tmp44_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp44_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp47_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->_tmp44_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3516 "media-manager.c"
	} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3520 "media-manager.c"
	}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->_tmp44_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3540 "media-manager.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3544 "media-manager.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 3550 "media-manager.c"
}


BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self) {
	BoxesOSDatabase* result;
	BoxesOSDatabase* _tmp0_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_os_db;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 3565 "media-manager.c"
}


static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value) {
	BoxesOSDatabase* _tmp0_ = NULL;
	BoxesOSDatabase* _tmp1_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv->_os_db = _tmp1_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "os-db");
#line 3584 "media-manager.c"
}


GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self) {
	GUdevClient* result;
	GUdevClient* _tmp0_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_client;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 3599 "media-manager.c"
}


static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value) {
	GUdevClient* _tmp0_ = NULL;
	GUdevClient* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv->_client = _tmp1_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "client");
#line 3618 "media-manager.c"
}


static void boxes_media_manager_class_init (BoxesMediaManagerClass * klass) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_type_class_add_private (klass, sizeof (BoxesMediaManagerPrivate));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_media_manager_get_property;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_media_manager_set_property;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_media_manager_finalize;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_OS_DB, g_param_spec_object ("os-db", "os-db", "os-db", BOXES_TYPE_OS_DATABASE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_CLIENT, g_param_spec_object ("client", "client", "client", g_udev_client_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3637 "media-manager.c"
}


static void boxes_media_manager_instance_init (BoxesMediaManager * self) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv = BOXES_MEDIA_MANAGER_GET_PRIVATE (self);
#line 3644 "media-manager.c"
}


static void boxes_media_manager_finalize (GObject* obj) {
	BoxesMediaManager * self;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->connection);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (boxes_media_manager_parent_class)->finalize (obj);
#line 3660 "media-manager.c"
}


GType boxes_media_manager_get_type (void) {
	static volatile gsize boxes_media_manager_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_media_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMediaManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_media_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMediaManager), 0, (GInstanceInitFunc) boxes_media_manager_instance_init, NULL };
		GType boxes_media_manager_type_id;
		boxes_media_manager_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesMediaManager", &g_define_type_info, 0);
		g_once_init_leave (&boxes_media_manager_type_id__volatile, boxes_media_manager_type_id);
	}
	return boxes_media_manager_type_id__volatile;
}


static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_os_db (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_client (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3693 "media-manager.c"
		default:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3699 "media-manager.c"
	}
}


static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_os_db (self, g_value_get_object (value));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_client (self, g_value_get_object (value));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3721 "media-manager.c"
		default:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3727 "media-manager.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3735 "media-manager.c"
		int i;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3743 "media-manager.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 3755 "media-manager.c"
}



